# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.1.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.usage_get200_response import UsageGet200Response

class TestUsageGet200Response(unittest.TestCase):
    """UsageGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsageGet200Response:
        """Test UsageGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsageGet200Response`
        """
        model = UsageGet200Response()
        if include_optional:
            return UsageGet200Response(
                period_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                period_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan = '',
                endpoints = qoery.models._usage_get_200_response_endpoints._usage_get_200_response_endpoints(
                    nl = qoery.models._usage_get_200_response_endpoints_nl._usage_get_200_response_endpoints_nl(
                        calls_used = 56, 
                        calls_limit = '', 
                        tokens_in = 56, 
                        tokens_out = 56, 
                        errors = 56, 
                        remaining = 56, ), 
                    sql = qoery.models._usage_get_200_response_endpoints_nl._usage_get_200_response_endpoints_nl(
                        calls_used = 56, 
                        calls_limit = '', 
                        tokens_in = 56, 
                        tokens_out = 56, 
                        errors = 56, 
                        remaining = 56, ), 
                    scrape = , )
            )
        else:
            return UsageGet200Response(
                period_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                period_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan = '',
                endpoints = qoery.models._usage_get_200_response_endpoints._usage_get_200_response_endpoints(
                    nl = qoery.models._usage_get_200_response_endpoints_nl._usage_get_200_response_endpoints_nl(
                        calls_used = 56, 
                        calls_limit = '', 
                        tokens_in = 56, 
                        tokens_out = 56, 
                        errors = 56, 
                        remaining = 56, ), 
                    sql = qoery.models._usage_get_200_response_endpoints_nl._usage_get_200_response_endpoints_nl(
                        calls_used = 56, 
                        calls_limit = '', 
                        tokens_in = 56, 
                        tokens_out = 56, 
                        errors = 56, 
                        remaining = 56, ), 
                    scrape = , ),
        )
        """

    def testUsageGet200Response(self):
        """Test UsageGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
