# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.1.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.api.queries_api import QueriesApi


class TestQueriesApi(unittest.TestCase):
    """QueriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = QueriesApi()

    def tearDown(self) -> None:
        pass

    def test_query_nl_post(self) -> None:
        """Test case for query_nl_post

        Natural Language Query
        """
        pass

    def test_query_sql_post(self) -> None:
        """Test case for query_sql_post

        SQL Query
        """
        pass


if __name__ == '__main__':
    unittest.main()
