# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.1.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.scrape_response import ScrapeResponse

class TestScrapeResponse(unittest.TestCase):
    """ScrapeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScrapeResponse:
        """Test ScrapeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScrapeResponse`
        """
        model = ScrapeResponse()
        if include_optional:
            return ScrapeResponse(
                series = [
                    qoery.models._query_nl_post_200_response_series_inner._query_nl_post_200_response_series_inner(
                        id = '', 
                        name = '', 
                        entity = qoery.models._query_nl_post_200_response_series_inner_entity._query_nl_post_200_response_series_inner_entity(
                            id = '', 
                            name = '', ), 
                        metric = qoery.models._query_nl_post_200_response_series_inner_metric._query_nl_post_200_response_series_inner_metric(
                            id = '', 
                            name = '', ), 
                        unit = qoery.models._query_nl_post_200_response_series_inner_unit._query_nl_post_200_response_series_inner_unit(
                            id = '', 
                            name = '', 
                            symbol = '', ), 
                        frequency = '', 
                        description = '', 
                        labels = { }, 
                        observations = [
                            qoery.models._query_nl_post_200_response_series_inner_observations_inner._query_nl_post_200_response_series_inner_observations_inner(
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                value = null, )
                            ], )
                    ],
                artifacts = qoery.models._scrape_post_200_response_artifacts._scrape_post_200_response_artifacts(
                    html_url = '', 
                    markdown_url = '', 
                    tables_base_url = '', ),
                cached = True,
                source_id = '',
                metadata = { },
                html = '',
                markdown = ''
            )
        else:
            return ScrapeResponse(
                series = [
                    qoery.models._query_nl_post_200_response_series_inner._query_nl_post_200_response_series_inner(
                        id = '', 
                        name = '', 
                        entity = qoery.models._query_nl_post_200_response_series_inner_entity._query_nl_post_200_response_series_inner_entity(
                            id = '', 
                            name = '', ), 
                        metric = qoery.models._query_nl_post_200_response_series_inner_metric._query_nl_post_200_response_series_inner_metric(
                            id = '', 
                            name = '', ), 
                        unit = qoery.models._query_nl_post_200_response_series_inner_unit._query_nl_post_200_response_series_inner_unit(
                            id = '', 
                            name = '', 
                            symbol = '', ), 
                        frequency = '', 
                        description = '', 
                        labels = { }, 
                        observations = [
                            qoery.models._query_nl_post_200_response_series_inner_observations_inner._query_nl_post_200_response_series_inner_observations_inner(
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                value = null, )
                            ], )
                    ],
        )
        """

    def testScrapeResponse(self):
        """Test ScrapeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
