# coding: utf-8

# flake8: noqa

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.2.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.2.0"

# Define package exports
__all__ = [
    "QueriesApi",
    "UsageApi",
    "WebScrapingApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ErrorResponse",
    "NLQueryRequest",
    "QueryNlPost200Response",
    "QueryNlPost200ResponseMeta",
    "QueryNlPost200ResponseMetaPage",
    "QueryNlPost200ResponseSeriesInner",
    "QueryNlPost200ResponseSeriesInnerEntity",
    "QueryNlPost200ResponseSeriesInnerMetric",
    "QueryNlPost200ResponseSeriesInnerObservationsInner",
    "QueryNlPost200ResponseSeriesInnerObservationsInnerValue",
    "QueryNlPost200ResponseSeriesInnerUnit",
    "QueryNlPost400Response",
    "QueryNlPostRequest",
    "QueryResponse",
    "QuerySqlPostRequest",
    "SQLQueryRequest",
    "ScrapePost200Response",
    "ScrapePost200ResponseArtifacts",
    "ScrapePost200ResponseMetadata",
    "ScrapePostRequest",
    "ScrapeResponse",
    "URLRequest",
    "UsageGet200Response",
    "UsageGet200ResponseEndpoints",
    "UsageGet200ResponseEndpointsNl",
    "UsageStats",
]

# import apis into sdk package
from qoery.api.queries_api import QueriesApi as QueriesApi
from qoery.api.usage_api import UsageApi as UsageApi
from qoery.api.web_scraping_api import WebScrapingApi as WebScrapingApi

# import ApiClient
from qoery.api_response import ApiResponse as ApiResponse
from qoery.api_client import ApiClient as ApiClient
from qoery.configuration import Configuration as Configuration
from qoery.exceptions import OpenApiException as OpenApiException
from qoery.exceptions import ApiTypeError as ApiTypeError
from qoery.exceptions import ApiValueError as ApiValueError
from qoery.exceptions import ApiKeyError as ApiKeyError
from qoery.exceptions import ApiAttributeError as ApiAttributeError
from qoery.exceptions import ApiException as ApiException

# import models into sdk package
from qoery.models.error_response import ErrorResponse as ErrorResponse
from qoery.models.nl_query_request import NLQueryRequest as NLQueryRequest
from qoery.models.query_nl_post200_response import QueryNlPost200Response as QueryNlPost200Response
from qoery.models.query_nl_post200_response_meta import QueryNlPost200ResponseMeta as QueryNlPost200ResponseMeta
from qoery.models.query_nl_post200_response_meta_page import QueryNlPost200ResponseMetaPage as QueryNlPost200ResponseMetaPage
from qoery.models.query_nl_post200_response_series_inner import QueryNlPost200ResponseSeriesInner as QueryNlPost200ResponseSeriesInner
from qoery.models.query_nl_post200_response_series_inner_entity import QueryNlPost200ResponseSeriesInnerEntity as QueryNlPost200ResponseSeriesInnerEntity
from qoery.models.query_nl_post200_response_series_inner_metric import QueryNlPost200ResponseSeriesInnerMetric as QueryNlPost200ResponseSeriesInnerMetric
from qoery.models.query_nl_post200_response_series_inner_observations_inner import QueryNlPost200ResponseSeriesInnerObservationsInner as QueryNlPost200ResponseSeriesInnerObservationsInner
from qoery.models.query_nl_post200_response_series_inner_observations_inner_value import QueryNlPost200ResponseSeriesInnerObservationsInnerValue as QueryNlPost200ResponseSeriesInnerObservationsInnerValue
from qoery.models.query_nl_post200_response_series_inner_unit import QueryNlPost200ResponseSeriesInnerUnit as QueryNlPost200ResponseSeriesInnerUnit
from qoery.models.query_nl_post400_response import QueryNlPost400Response as QueryNlPost400Response
from qoery.models.query_nl_post_request import QueryNlPostRequest as QueryNlPostRequest
from qoery.models.query_response import QueryResponse as QueryResponse
from qoery.models.query_sql_post_request import QuerySqlPostRequest as QuerySqlPostRequest
from qoery.models.sql_query_request import SQLQueryRequest as SQLQueryRequest
from qoery.models.scrape_post200_response import ScrapePost200Response as ScrapePost200Response
from qoery.models.scrape_post200_response_artifacts import ScrapePost200ResponseArtifacts as ScrapePost200ResponseArtifacts
from qoery.models.scrape_post200_response_metadata import ScrapePost200ResponseMetadata as ScrapePost200ResponseMetadata
from qoery.models.scrape_post_request import ScrapePostRequest as ScrapePostRequest
from qoery.models.scrape_response import ScrapeResponse as ScrapeResponse
from qoery.models.url_request import URLRequest as URLRequest
from qoery.models.usage_get200_response import UsageGet200Response as UsageGet200Response
from qoery.models.usage_get200_response_endpoints import UsageGet200ResponseEndpoints as UsageGet200ResponseEndpoints
from qoery.models.usage_get200_response_endpoints_nl import UsageGet200ResponseEndpointsNl as UsageGet200ResponseEndpointsNl
from qoery.models.usage_stats import UsageStats as UsageStats
